/* GomObject.c generated by valac 0.34.6, the Vala compiler
 * generated from GomObject.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/*
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>


#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_GOM_OBJECT (gxml_gom_object_get_type ())
#define GXML_GOM_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_OBJECT, GXmlGomObject))
#define GXML_IS_GOM_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_OBJECT))
#define GXML_GOM_OBJECT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_OBJECT, GXmlGomObjectIface))

typedef struct _GXmlGomObject GXmlGomObject;
typedef struct _GXmlGomObjectIface GXmlGomObjectIface;
#define _g_param_spec_unref0(var) ((var == NULL) ? NULL : (var = (g_param_spec_unref (var), NULL)))
#define __g_list_free__g_param_spec_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_param_spec_unref0_ (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define GXML_TYPE_GOM_COLLECTION (gxml_gom_collection_get_type ())
#define GXML_GOM_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_COLLECTION, GXmlGomCollection))
#define GXML_IS_GOM_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_COLLECTION))
#define GXML_GOM_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_COLLECTION, GXmlGomCollectionIface))

typedef struct _GXmlGomCollection GXmlGomCollection;
typedef struct _GXmlGomCollectionIface GXmlGomCollectionIface;

#define GXML_TYPE_GOM_NODE (gxml_gom_node_get_type ())
#define GXML_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE, GXmlGomNode))
#define GXML_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))
#define GXML_IS_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE))
#define GXML_IS_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE))
#define GXML_GOM_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))

typedef struct _GXmlGomNode GXmlGomNode;
typedef struct _GXmlGomNodeClass GXmlGomNodeClass;

#define GXML_TYPE_GOM_ELEMENT (gxml_gom_element_get_type ())
#define GXML_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElement))
#define GXML_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))
#define GXML_IS_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ELEMENT))
#define GXML_IS_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ELEMENT))
#define GXML_GOM_ELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))

typedef struct _GXmlGomElement GXmlGomElement;
typedef struct _GXmlGomElementClass GXmlGomElementClass;

#define GXML_TYPE_GOM_PROPERTY (gxml_gom_property_get_type ())
#define GXML_GOM_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_PROPERTY, GXmlGomProperty))
#define GXML_IS_GOM_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_PROPERTY))
#define GXML_GOM_PROPERTY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_GOM_PROPERTY, GXmlGomPropertyIface))

typedef struct _GXmlGomProperty GXmlGomProperty;
typedef struct _GXmlGomPropertyIface GXmlGomPropertyIface;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlGomObjectIface {
	GTypeInterface parent_iface;
	GList* (*get_properties_list) (GXmlGomObject* self);
	GParamSpec* (*find_property_name) (GXmlGomObject* self, const gchar* pname);
	GParamSpec* (*find_object_property_name) (GXmlGomObject* self, const gchar* pname);
	GList* (*get_property_element_list) (GXmlGomObject* self);
	gchar* (*get_property_string) (GXmlGomObject* self, GParamSpec* prop);
	gchar* (*get_attribute) (GXmlGomObject* self, const gchar* name);
	gboolean (*set_attribute) (GXmlGomObject* self, const gchar* name, const gchar* val);
	GXmlDomElement* (*get_child) (GXmlGomObject* self, const gchar* name);
	GXmlDomElementList* (*find_elements) (GXmlGomObject* self, const gchar* name);
	gboolean (*remove_attribute) (GXmlGomObject* self, const gchar* name);
	gboolean (*set_instance_property) (GXmlGomObject* self, const gchar* name);
	void (*clean_property_elements) (GXmlGomObject* self, const gchar* name, GError** error);
};

struct _GXmlGomCollectionIface {
	GTypeInterface parent_iface;
	void (*search) (GXmlGomCollection* self, GError** error);
	GXmlDomElement* (*get_item) (GXmlGomCollection* self, gint index, GError** error);
	void (*append) (GXmlGomCollection* self, GXmlDomElement* node, GError** error);
	void (*initialize) (GXmlGomCollection* self, GType t, GError** error);
	GXmlGomElement* (*create_item) (GXmlGomCollection* self);
	gboolean (*validate_append) (GXmlGomCollection* self, gint index, GXmlDomElement* element, GError** error);
	GQueue* (*get_nodes_index) (GXmlGomCollection* self);
	GXmlGomElement* (*get_element) (GXmlGomCollection* self);
	void (*set_element) (GXmlGomCollection* self, GXmlGomElement* value);
	const gchar* (*get_items_name) (GXmlGomCollection* self);
	GType (*get_items_type) (GXmlGomCollection* self);
	void (*set_items_type) (GXmlGomCollection* self, GType value);
	gint (*get_length) (GXmlGomCollection* self);
};

struct _GXmlGomPropertyIface {
	GTypeInterface parent_iface;
	gboolean (*validate_value) (GXmlGomProperty* self, const gchar* val);
	gchar* (*get_value) (GXmlGomProperty* self);
	void (*set_value) (GXmlGomProperty* self, const gchar* value);
};

typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()


GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_object_get_type (void) G_GNUC_CONST;
GList* gxml_gom_object_get_properties_list (GXmlGomObject* self);
static GList* gxml_gom_object_real_get_properties_list (GXmlGomObject* self);
static void _g_param_spec_unref0_ (gpointer var);
static void _g_list_free__g_param_spec_unref0_ (GList* self);
GParamSpec* gxml_gom_object_find_property_name (GXmlGomObject* self, const gchar* pname);
static GParamSpec* gxml_gom_object_real_find_property_name (GXmlGomObject* self, const gchar* pname);
GParamSpec* gxml_gom_object_find_object_property_name (GXmlGomObject* self, const gchar* pname);
static GParamSpec* gxml_gom_object_real_find_object_property_name (GXmlGomObject* self, const gchar* pname);
GType gxml_gom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_element_get_type (void) G_GNUC_CONST;
GType gxml_gom_collection_get_type (void) G_GNUC_CONST;
GList* gxml_gom_object_get_property_element_list (GXmlGomObject* self);
static GList* gxml_gom_object_real_get_property_element_list (GXmlGomObject* self);
gchar* gxml_gom_object_get_property_string (GXmlGomObject* self, GParamSpec* prop);
static gchar* gxml_gom_object_real_get_property_string (GXmlGomObject* self, GParamSpec* prop);
GType gxml_gom_property_get_type (void) G_GNUC_CONST;
gchar* gxml_gom_property_get_value (GXmlGomProperty* self);
gchar* gxml_enumeration_get_string (GType enumeration, gint val, gboolean use_nick, gboolean camelcase, GError** error);
gchar* gxml_gom_object_get_attribute (GXmlGomObject* self, const gchar* name);
static gchar* gxml_gom_object_real_get_attribute (GXmlGomObject* self, const gchar* name);
gboolean gxml_gom_object_set_attribute (GXmlGomObject* self, const gchar* name, const gchar* val);
static gboolean gxml_gom_object_real_set_attribute (GXmlGomObject* self, const gchar* name, const gchar* val);
void gxml_gom_property_set_value (GXmlGomProperty* self, const gchar* value);
GEnumValue* gxml_enumeration_parse (GType enumeration, const gchar* val, GError** error);
GXmlDomElement* gxml_gom_object_get_child (GXmlGomObject* self, const gchar* name);
static GXmlDomElement* gxml_gom_object_real_get_child (GXmlGomObject* self, const gchar* name);
gboolean gxml_dom_node_has_child_nodes (GXmlDomNode* self);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name (GXmlDomElement* self, const gchar* local_name);
GXmlDomElement* gxml_dom_html_collection_item (GXmlDomHTMLCollection* self, gint index);
GXmlDomElementList* gxml_gom_object_find_elements (GXmlGomObject* self, const gchar* name);
static GXmlDomElementList* gxml_gom_object_real_find_elements (GXmlGomObject* self, const gchar* name);
GXmlDomElementList* gxml_dom_element_list_new (void);
GXmlDomElementList* gxml_dom_element_list_construct (GType object_type);
GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self);
gchar* gxml_dom_element_get_local_name (GXmlDomElement* self);
gboolean gxml_gom_object_remove_attribute (GXmlGomObject* self, const gchar* name);
static gboolean gxml_gom_object_real_remove_attribute (GXmlGomObject* self, const gchar* name);
gboolean gxml_gom_object_set_instance_property (GXmlGomObject* self, const gchar* name);
static gboolean gxml_gom_object_real_set_instance_property (GXmlGomObject* self, const gchar* name);
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_append_child (GXmlDomNode* self, GXmlDomNode* node, GError** error);
void gxml_gom_object_clean_property_elements (GXmlGomObject* self, const gchar* name, GError** error);
static void gxml_gom_object_real_clean_property_elements (GXmlGomObject* self, const gchar* name, GError** error);
GQuark gxml_dom_error_quark (void);
gint gxml_dom_html_collection_get_length (GXmlDomHTMLCollection* self);
void gxml_dom_child_node_remove (GXmlDomChildNode* self);


/**
   * Returns a list with all properties' nick with "::" prefix. Nick name,
   * with "::" prefix will be used on serialization to an attribute's name.
   */
static gpointer _g_param_spec_ref0 (gpointer self) {
	return self ? g_param_spec_ref (self) : NULL;
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = needle;
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
	result = _tmp1_ != NULL;
	return result;
}


static void _g_param_spec_unref0_ (gpointer var) {
	(var == NULL) ? NULL : (var = (g_param_spec_unref (var), NULL));
}


static void _g_list_free__g_param_spec_unref0_ (GList* self) {
	g_list_foreach (self, (GFunc) _g_param_spec_unref0_, NULL);
	g_list_free (self);
}


static GList* gxml_gom_object_real_get_properties_list (GXmlGomObject* self) {
	GList* result = NULL;
	GList* l = NULL;
	GObjectClass* _tmp0_ = NULL;
	guint _tmp1_;
	GParamSpec** _tmp2_ = NULL;
	l = NULL;
	_tmp0_ = G_OBJECT_GET_CLASS ((GObject*) self);
	_tmp2_ = g_object_class_list_properties (_tmp0_, &_tmp1_);
	{
		GParamSpec** spec_collection = NULL;
		gint spec_collection_length1 = 0;
		gint _spec_collection_size_ = 0;
		gint spec_it = 0;
		spec_collection = _tmp2_;
		spec_collection_length1 = _tmp1_;
		for (spec_it = 0; spec_it < _tmp1_; spec_it = spec_it + 1) {
			GParamSpec* _tmp3_ = NULL;
			GParamSpec* spec = NULL;
			_tmp3_ = _g_param_spec_ref0 (spec_collection[spec_it]);
			spec = _tmp3_;
			{
				GParamSpec* _tmp4_ = NULL;
				const gchar* _tmp5_ = NULL;
				gboolean _tmp6_ = FALSE;
				_tmp4_ = spec;
				_tmp5_ = g_param_spec_get_nick (_tmp4_);
				_tmp6_ = string_contains (_tmp5_, "::");
				if (_tmp6_) {
					GParamSpec* _tmp7_ = NULL;
					GParamSpec* _tmp8_ = NULL;
					_tmp7_ = spec;
					_tmp8_ = _g_param_spec_ref0 (_tmp7_);
					l = g_list_append (l, _tmp8_);
				}
				_g_param_spec_unref0 (spec);
			}
		}
		spec_collection = (g_free (spec_collection), NULL);
	}
	result = l;
	return result;
}


GList* gxml_gom_object_get_properties_list (GXmlGomObject* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->get_properties_list (self);
}


/**
   * Returns property's {@link GLib.ParamSpec} based on given nick. This function is
   * case insensitive.
   */
static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (old != NULL, NULL);
	g_return_val_if_fail (replacement != NULL, NULL);
	{
		GRegex* regex = NULL;
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GRegex* _tmp3_ = NULL;
		GRegex* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GRegex* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		_tmp0_ = old;
		_tmp1_ = g_regex_escape_string (_tmp0_, -1);
		_tmp2_ = _tmp1_;
		_tmp3_ = g_regex_new (_tmp2_, 0, 0, &_inner_error_);
		_tmp4_ = _tmp3_;
		_g_free0 (_tmp2_);
		regex = _tmp4_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			if (_inner_error_->domain == G_REGEX_ERROR) {
				goto __catch20_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return NULL;
		}
		_tmp6_ = regex;
		_tmp7_ = replacement;
		_tmp8_ = g_regex_replace_literal (_tmp6_, self, (gssize) -1, 0, _tmp7_, 0, &_inner_error_);
		_tmp5_ = _tmp8_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			_g_regex_unref0 (regex);
			if (_inner_error_->domain == G_REGEX_ERROR) {
				goto __catch20_g_regex_error;
			}
			_g_regex_unref0 (regex);
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return NULL;
		}
		_tmp9_ = _tmp5_;
		_tmp5_ = NULL;
		result = _tmp9_;
		_g_free0 (_tmp5_);
		_g_regex_unref0 (regex);
		return result;
	}
	goto __finally20;
	__catch20_g_regex_error:
	{
		GError* e = NULL;
		e = _inner_error_;
		_inner_error_ = NULL;
		g_assert_not_reached ();
		_g_error_free0 (e);
	}
	__finally20:
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return NULL;
	}
}


static GParamSpec* gxml_gom_object_real_find_property_name (GXmlGomObject* self, const gchar* pname) {
	GParamSpec* result = NULL;
	GObjectClass* _tmp0_ = NULL;
	guint _tmp1_;
	GParamSpec** _tmp2_ = NULL;
	g_return_val_if_fail (pname != NULL, NULL);
	_tmp0_ = G_OBJECT_GET_CLASS ((GObject*) self);
	_tmp2_ = g_object_class_list_properties (_tmp0_, &_tmp1_);
	{
		GParamSpec** spec_collection = NULL;
		gint spec_collection_length1 = 0;
		gint _spec_collection_size_ = 0;
		gint spec_it = 0;
		spec_collection = _tmp2_;
		spec_collection_length1 = _tmp1_;
		for (spec_it = 0; spec_it < _tmp1_; spec_it = spec_it + 1) {
			GParamSpec* _tmp3_ = NULL;
			GParamSpec* spec = NULL;
			_tmp3_ = _g_param_spec_ref0 (spec_collection[spec_it]);
			spec = _tmp3_;
			{
				gchar* name = NULL;
				GParamSpec* _tmp4_ = NULL;
				const gchar* _tmp5_ = NULL;
				gchar* _tmp6_ = NULL;
				const gchar* _tmp7_ = NULL;
				gboolean _tmp8_ = FALSE;
				_tmp4_ = spec;
				_tmp5_ = g_param_spec_get_nick (_tmp4_);
				_tmp6_ = g_strdup (_tmp5_);
				name = _tmp6_;
				_tmp7_ = name;
				_tmp8_ = string_contains (_tmp7_, "::");
				if (_tmp8_) {
					const gchar* _tmp9_ = NULL;
					gchar* _tmp10_ = NULL;
					const gchar* _tmp11_ = NULL;
					gchar* _tmp12_ = NULL;
					gchar* _tmp13_ = NULL;
					const gchar* _tmp14_ = NULL;
					gchar* _tmp15_ = NULL;
					gchar* _tmp16_ = NULL;
					gboolean _tmp17_ = FALSE;
					_tmp9_ = name;
					_tmp10_ = string_replace (_tmp9_, "::", "");
					_g_free0 (name);
					name = _tmp10_;
					_tmp11_ = name;
					_tmp12_ = g_utf8_strdown (_tmp11_, (gssize) -1);
					_tmp13_ = _tmp12_;
					_tmp14_ = pname;
					_tmp15_ = g_utf8_strdown (_tmp14_, (gssize) -1);
					_tmp16_ = _tmp15_;
					_tmp17_ = g_strcmp0 (_tmp13_, _tmp16_) == 0;
					_g_free0 (_tmp16_);
					_g_free0 (_tmp13_);
					if (_tmp17_) {
						result = spec;
						_g_free0 (name);
						spec_collection = (g_free (spec_collection), NULL);
						return result;
					}
				}
				_g_free0 (name);
				_g_param_spec_unref0 (spec);
			}
		}
		spec_collection = (g_free (spec_collection), NULL);
	}
	result = NULL;
	return result;
}


GParamSpec* gxml_gom_object_find_property_name (GXmlGomObject* self, const gchar* pname) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->find_property_name (self, pname);
}


/**
   * Returns a {@link GomObject} or a {@link GomCollection} property's
   * {@link GLib.ParamSpec} based on given name. This method is
   * case insensitive.
   *
   * This method will check if nick's name is equal than given name
   * in order to avoid use canonical names like "your-name" if your
   * property is your_name; so you can se nick to "YourName" to find
   * and instantiate it.
   */
static GParamSpec* gxml_gom_object_real_find_object_property_name (GXmlGomObject* self, const gchar* pname) {
	GParamSpec* result = NULL;
	GObjectClass* _tmp0_ = NULL;
	guint _tmp1_;
	GParamSpec** _tmp2_ = NULL;
	g_return_val_if_fail (pname != NULL, NULL);
	_tmp0_ = G_OBJECT_GET_CLASS ((GObject*) self);
	_tmp2_ = g_object_class_list_properties (_tmp0_, &_tmp1_);
	{
		GParamSpec** spec_collection = NULL;
		gint spec_collection_length1 = 0;
		gint _spec_collection_size_ = 0;
		gint spec_it = 0;
		spec_collection = _tmp2_;
		spec_collection_length1 = _tmp1_;
		for (spec_it = 0; spec_it < _tmp1_; spec_it = spec_it + 1) {
			GParamSpec* _tmp3_ = NULL;
			GParamSpec* spec = NULL;
			_tmp3_ = _g_param_spec_ref0 (spec_collection[spec_it]);
			spec = _tmp3_;
			{
				gchar* name = NULL;
				const gchar* _tmp4_ = NULL;
				gchar* _tmp5_ = NULL;
				const gchar* _tmp6_ = NULL;
				gboolean _tmp7_ = FALSE;
				gchar* nick = NULL;
				GParamSpec* _tmp10_ = NULL;
				const gchar* _tmp11_ = NULL;
				gchar* _tmp12_ = NULL;
				const gchar* _tmp13_ = NULL;
				gboolean _tmp14_ = FALSE;
				gchar* sname = NULL;
				GParamSpec* _tmp17_ = NULL;
				const gchar* _tmp18_ = NULL;
				gchar* _tmp19_ = NULL;
				gboolean _tmp20_ = FALSE;
				const gchar* _tmp21_ = NULL;
				const gchar* _tmp22_ = NULL;
				_tmp4_ = pname;
				_tmp5_ = g_utf8_strdown (_tmp4_, (gssize) -1);
				name = _tmp5_;
				_tmp6_ = name;
				_tmp7_ = string_contains (_tmp6_, "::");
				if (_tmp7_) {
					const gchar* _tmp8_ = NULL;
					gchar* _tmp9_ = NULL;
					_tmp8_ = name;
					_tmp9_ = string_replace (_tmp8_, "::", "");
					_g_free0 (name);
					name = _tmp9_;
				}
				_tmp10_ = spec;
				_tmp11_ = g_param_spec_get_nick (_tmp10_);
				_tmp12_ = g_utf8_strdown (_tmp11_, (gssize) -1);
				nick = _tmp12_;
				_tmp13_ = nick;
				_tmp14_ = string_contains (_tmp13_, "::");
				if (_tmp14_) {
					const gchar* _tmp15_ = NULL;
					gchar* _tmp16_ = NULL;
					_tmp15_ = nick;
					_tmp16_ = string_replace (_tmp15_, "::", "");
					_g_free0 (nick);
					nick = _tmp16_;
				}
				_tmp17_ = spec;
				_tmp18_ = _tmp17_->name;
				_tmp19_ = g_utf8_strdown (_tmp18_, (gssize) -1);
				sname = _tmp19_;
				_tmp21_ = sname;
				_tmp22_ = name;
				if (g_strcmp0 (_tmp21_, _tmp22_) == 0) {
					_tmp20_ = TRUE;
				} else {
					const gchar* _tmp23_ = NULL;
					const gchar* _tmp24_ = NULL;
					_tmp23_ = nick;
					_tmp24_ = name;
					_tmp20_ = g_strcmp0 (_tmp23_, _tmp24_) == 0;
				}
				if (_tmp20_) {
					gboolean _tmp25_ = FALSE;
					GParamSpec* _tmp26_ = NULL;
					GType _tmp27_ = 0UL;
					gboolean _tmp28_ = FALSE;
					_tmp26_ = spec;
					_tmp27_ = _tmp26_->value_type;
					_tmp28_ = g_type_is_a (_tmp27_, GXML_TYPE_GOM_OBJECT);
					if (_tmp28_) {
						_tmp25_ = TRUE;
					} else {
						GParamSpec* _tmp29_ = NULL;
						GType _tmp30_ = 0UL;
						gboolean _tmp31_ = FALSE;
						_tmp29_ = spec;
						_tmp30_ = _tmp29_->value_type;
						_tmp31_ = g_type_is_a (_tmp30_, GXML_TYPE_GOM_COLLECTION);
						_tmp25_ = _tmp31_;
					}
					if (_tmp25_) {
						result = spec;
						_g_free0 (sname);
						_g_free0 (nick);
						_g_free0 (name);
						spec_collection = (g_free (spec_collection), NULL);
						return result;
					}
				}
				_g_free0 (sname);
				_g_free0 (nick);
				_g_free0 (name);
				_g_param_spec_unref0 (spec);
			}
		}
		spec_collection = (g_free (spec_collection), NULL);
	}
	result = NULL;
	return result;
}


GParamSpec* gxml_gom_object_find_object_property_name (GXmlGomObject* self, const gchar* pname) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->find_object_property_name (self, pname);
}


/**
   * Returns a list of names for all {@link DomElement}
   * present as object's properties.
   */
static GList* gxml_gom_object_real_get_property_element_list (GXmlGomObject* self) {
	GList* result = NULL;
	GList* l = NULL;
	GObjectClass* _tmp0_ = NULL;
	guint _tmp1_;
	GParamSpec** _tmp2_ = NULL;
	l = NULL;
	_tmp0_ = G_OBJECT_GET_CLASS ((GObject*) self);
	_tmp2_ = g_object_class_list_properties (_tmp0_, &_tmp1_);
	{
		GParamSpec** spec_collection = NULL;
		gint spec_collection_length1 = 0;
		gint _spec_collection_size_ = 0;
		gint spec_it = 0;
		spec_collection = _tmp2_;
		spec_collection_length1 = _tmp1_;
		for (spec_it = 0; spec_it < _tmp1_; spec_it = spec_it + 1) {
			GParamSpec* _tmp3_ = NULL;
			GParamSpec* spec = NULL;
			_tmp3_ = _g_param_spec_ref0 (spec_collection[spec_it]);
			spec = _tmp3_;
			{
				gboolean _tmp4_ = FALSE;
				GParamSpec* _tmp5_ = NULL;
				GType _tmp6_ = 0UL;
				gboolean _tmp7_ = FALSE;
				_tmp5_ = spec;
				_tmp6_ = _tmp5_->value_type;
				_tmp7_ = g_type_is_a (_tmp6_, GXML_TYPE_GOM_OBJECT);
				if (_tmp7_) {
					_tmp4_ = TRUE;
				} else {
					GParamSpec* _tmp8_ = NULL;
					GType _tmp9_ = 0UL;
					gboolean _tmp10_ = FALSE;
					_tmp8_ = spec;
					_tmp9_ = _tmp8_->value_type;
					_tmp10_ = g_type_is_a (_tmp9_, GXML_TYPE_GOM_COLLECTION);
					_tmp4_ = _tmp10_;
				}
				if (_tmp4_) {
					GParamSpec* _tmp11_ = NULL;
					GParamSpec* _tmp12_ = NULL;
					_tmp11_ = spec;
					_tmp12_ = _g_param_spec_ref0 (_tmp11_);
					l = g_list_append (l, _tmp12_);
				}
				_g_param_spec_unref0 (spec);
			}
		}
		spec_collection = (g_free (spec_collection), NULL);
	}
	result = l;
	return result;
}


GList* gxml_gom_object_get_property_element_list (GXmlGomObject* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->get_property_element_list (self);
}


/**
   * Returns an string representation of an Object's property.
   */
static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


static gchar* double_to_string (gdouble self) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	_tmp0_ = g_new0 (gchar, G_ASCII_DTOSTR_BUF_SIZE);
	_tmp1_ = _tmp0_;
	_tmp1__length1 = G_ASCII_DTOSTR_BUF_SIZE;
	_tmp2_ = g_ascii_dtostr (_tmp1_, G_ASCII_DTOSTR_BUF_SIZE, self);
	_tmp3_ = g_strdup (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp1_ = (g_free (_tmp1_), NULL);
	result = _tmp4_;
	return result;
}


static gchar* bool_to_string (gboolean self) {
	gchar* result = NULL;
	if (self) {
		gchar* _tmp0_ = NULL;
		_tmp0_ = g_strdup ("true");
		result = _tmp0_;
		return result;
	} else {
		gchar* _tmp1_ = NULL;
		_tmp1_ = g_strdup ("false");
		result = _tmp1_;
		return result;
	}
}


static gchar* gxml_gom_object_real_get_property_string (GXmlGomObject* self, GParamSpec* prop) {
	gchar* result = NULL;
	GValue v = {0};
	GParamSpec* _tmp0_ = NULL;
	GType _tmp1_ = 0UL;
	GValue _tmp2_ = {0};
	GParamSpec* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GParamSpec* _tmp5_ = NULL;
	GType _tmp6_ = 0UL;
	gboolean _tmp7_ = FALSE;
	GParamSpec* _tmp14_ = NULL;
	GType _tmp15_ = 0UL;
	gboolean _tmp16_ = FALSE;
	GParamSpec* _tmp19_ = NULL;
	GType _tmp20_ = 0UL;
	gboolean _tmp21_ = FALSE;
	GParamSpec* _tmp24_ = NULL;
	GType _tmp25_ = 0UL;
	gboolean _tmp26_ = FALSE;
	GParamSpec* _tmp29_ = NULL;
	GType _tmp30_ = 0UL;
	gboolean _tmp31_ = FALSE;
	GParamSpec* _tmp34_ = NULL;
	GType _tmp35_ = 0UL;
	gboolean _tmp36_ = FALSE;
	GParamSpec* _tmp39_ = NULL;
	GType _tmp40_ = 0UL;
	gboolean _tmp41_ = FALSE;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (prop != NULL, NULL);
	_tmp0_ = prop;
	_tmp1_ = _tmp0_->value_type;
	g_value_init (&_tmp2_, _tmp1_);
	v = _tmp2_;
	_tmp3_ = prop;
	_tmp4_ = _tmp3_->name;
	g_object_get_property ((GObject*) self, _tmp4_, &v);
	_tmp5_ = prop;
	_tmp6_ = _tmp5_->value_type;
	_tmp7_ = g_type_is_a (_tmp6_, GXML_TYPE_GOM_PROPERTY);
	if (_tmp7_) {
		GObject* so = NULL;
		GObject* _tmp8_ = NULL;
		GObject* _tmp9_ = NULL;
		GObject* _tmp10_ = NULL;
		GObject* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		_tmp8_ = g_value_get_object (&v);
		_tmp9_ = _g_object_ref0 (_tmp8_);
		so = _tmp9_;
		_tmp10_ = so;
		if (_tmp10_ == NULL) {
			result = NULL;
			_g_object_unref0 (so);
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			return result;
		}
		_tmp11_ = so;
		_tmp12_ = gxml_gom_property_get_value (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, GXML_TYPE_GOM_PROPERTY) ? ((GXmlGomProperty*) _tmp11_) : NULL);
		_tmp13_ = _tmp12_;
		result = _tmp13_;
		_g_object_unref0 (so);
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
		return result;
	}
	_tmp14_ = prop;
	_tmp15_ = _tmp14_->value_type;
	_tmp16_ = g_type_is_a (_tmp15_, G_TYPE_STRING);
	if (_tmp16_) {
		GValue _tmp17_ = {0};
		gchar* _tmp18_ = NULL;
		_tmp17_ = v;
		_tmp18_ = g_strdup (g_value_get_string (&_tmp17_));
		result = _tmp18_;
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
		return result;
	}
	_tmp19_ = prop;
	_tmp20_ = _tmp19_->value_type;
	_tmp21_ = g_type_is_a (_tmp20_, G_TYPE_INT);
	if (_tmp21_) {
		GValue _tmp22_ = {0};
		gchar* _tmp23_ = NULL;
		_tmp22_ = v;
		_tmp23_ = g_strdup_printf ("%i", g_value_get_int (&_tmp22_));
		result = _tmp23_;
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
		return result;
	}
	_tmp24_ = prop;
	_tmp25_ = _tmp24_->value_type;
	_tmp26_ = g_type_is_a (_tmp25_, G_TYPE_UINT);
	if (_tmp26_) {
		GValue _tmp27_ = {0};
		gchar* _tmp28_ = NULL;
		_tmp27_ = v;
		_tmp28_ = g_strdup_printf ("%u", g_value_get_uint (&_tmp27_));
		result = _tmp28_;
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
		return result;
	}
	_tmp29_ = prop;
	_tmp30_ = _tmp29_->value_type;
	_tmp31_ = g_type_is_a (_tmp30_, G_TYPE_DOUBLE);
	if (_tmp31_) {
		GValue _tmp32_ = {0};
		gchar* _tmp33_ = NULL;
		_tmp32_ = v;
		_tmp33_ = double_to_string (g_value_get_double (&_tmp32_));
		result = _tmp33_;
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
		return result;
	}
	_tmp34_ = prop;
	_tmp35_ = _tmp34_->value_type;
	_tmp36_ = g_type_is_a (_tmp35_, G_TYPE_BOOLEAN);
	if (_tmp36_) {
		GValue _tmp37_ = {0};
		gchar* _tmp38_ = NULL;
		_tmp37_ = v;
		_tmp38_ = bool_to_string (g_value_get_boolean (&_tmp37_));
		result = _tmp38_;
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
		return result;
	}
	_tmp39_ = prop;
	_tmp40_ = _tmp39_->value_type;
	_tmp41_ = g_type_is_a (_tmp40_, G_TYPE_ENUM);
	if (_tmp41_) {
		gint n = 0;
		gint _tmp42_ = 0;
		_tmp42_ = g_value_get_enum (&v);
		n = _tmp42_;
		{
			gchar* _tmp43_ = NULL;
			GParamSpec* _tmp44_ = NULL;
			GType _tmp45_ = 0UL;
			gint _tmp46_ = 0;
			gchar* _tmp47_ = NULL;
			gchar* _tmp48_ = NULL;
			_tmp44_ = prop;
			_tmp45_ = _tmp44_->value_type;
			_tmp46_ = n;
			_tmp47_ = gxml_enumeration_get_string (_tmp45_, _tmp46_, TRUE, TRUE, &_inner_error_);
			_tmp43_ = _tmp47_;
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				goto __catch21_g_error;
			}
			_tmp48_ = _tmp43_;
			_tmp43_ = NULL;
			result = _tmp48_;
			_g_free0 (_tmp43_);
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			return result;
		}
		goto __finally21;
		__catch21_g_error:
		{
			const gchar* _tmp49_ = NULL;
			g_clear_error (&_inner_error_);
			_inner_error_ = NULL;
			_tmp49_ = _ ("Enumeration is out of range");
			g_warning ("GomObject.vala:168: %s", _tmp49_);
		}
		__finally21:
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return NULL;
		}
	}
	result = NULL;
	G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
	return result;
}


gchar* gxml_gom_object_get_property_string (GXmlGomObject* self, GParamSpec* prop) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->get_property_string (self, prop);
}


/**
   * Search for properties in objects, it should be
   * an {@link GLib.Object}'s property. If found a
   * property with given name its value is returned
   * as string representation.
   *
   * If property is a {@link GomProperty}
   * returned value is a string representation according
   * with object implementation.
   *
   * If given property name is not found, then {@link DomElement.get_attribute}
   * is called.
   *
   * By default all {@link GLib.Object} are children of
   * this object, see {@link get_child}
   */
static gchar* gxml_gom_object_real_get_attribute (GXmlGomObject* self, const gchar* name) {
	gchar* result = NULL;
	GParamSpec* prop = NULL;
	const gchar* _tmp0_ = NULL;
	GParamSpec* _tmp1_ = NULL;
	GParamSpec* _tmp2_ = NULL;
	GParamSpec* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = name;
	_tmp1_ = gxml_gom_object_find_property_name (self, _tmp0_);
	prop = _tmp1_;
	_tmp2_ = prop;
	if (_tmp2_ == NULL) {
		result = NULL;
		_g_param_spec_unref0 (prop);
		return result;
	}
	_tmp3_ = prop;
	_tmp4_ = gxml_gom_object_get_property_string (self, _tmp3_);
	result = _tmp4_;
	_g_param_spec_unref0 (prop);
	return result;
}


gchar* gxml_gom_object_get_attribute (GXmlGomObject* self, const gchar* name) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->get_attribute (self, name);
}


/**
   * Search for a {@link GLib.Object} property with
   * given name, if found, given string representation
   * is used as value to property, using any required
   * transformation from string.
   *
   * By default all {@link GLib.Object} are children of
   * this object.
   */
static gdouble double_parse (const gchar* str) {
	gdouble result = 0.0;
	const gchar* _tmp0_ = NULL;
	gdouble _tmp1_ = 0.0;
	g_return_val_if_fail (str != NULL, 0.0);
	_tmp0_ = str;
	_tmp1_ = g_ascii_strtod (_tmp0_, NULL);
	result = _tmp1_;
	return result;
}


static gboolean bool_parse (const gchar* str) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	g_return_val_if_fail (str != NULL, FALSE);
	_tmp0_ = str;
	if (g_strcmp0 (_tmp0_, "true") == 0) {
		result = TRUE;
		return result;
	} else {
		result = FALSE;
		return result;
	}
}


static gboolean gxml_gom_object_real_set_attribute (GXmlGomObject* self, const gchar* name, const gchar* val) {
	gboolean result = FALSE;
	GParamSpec* prop = NULL;
	const gchar* _tmp0_ = NULL;
	GParamSpec* _tmp1_ = NULL;
	GParamSpec* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (name != NULL, FALSE);
	g_return_val_if_fail (val != NULL, FALSE);
	_tmp0_ = name;
	_tmp1_ = gxml_gom_object_find_property_name (self, _tmp0_);
	prop = _tmp1_;
	_tmp2_ = prop;
	if (_tmp2_ != NULL) {
		GValue v = {0};
		GParamSpec* _tmp3_ = NULL;
		GType _tmp4_ = 0UL;
		GValue _tmp5_ = {0};
		GParamSpec* _tmp6_ = NULL;
		GType _tmp7_ = 0UL;
		gboolean _tmp8_ = FALSE;
		GParamSpec* _tmp27_ = NULL;
		GType _tmp28_ = 0UL;
		gboolean _tmp29_ = FALSE;
		GParamSpec* _tmp34_ = NULL;
		GType _tmp35_ = 0UL;
		gboolean _tmp36_ = FALSE;
		GParamSpec* _tmp43_ = NULL;
		GType _tmp44_ = 0UL;
		gboolean _tmp45_ = FALSE;
		GParamSpec* _tmp52_ = NULL;
		GType _tmp53_ = 0UL;
		gboolean _tmp54_ = FALSE;
		GParamSpec* _tmp61_ = NULL;
		GType _tmp62_ = 0UL;
		gboolean _tmp63_ = FALSE;
		GParamSpec* _tmp70_ = NULL;
		GType _tmp71_ = 0UL;
		gboolean _tmp72_ = FALSE;
		_tmp3_ = prop;
		_tmp4_ = _tmp3_->value_type;
		g_value_init (&_tmp5_, _tmp4_);
		v = _tmp5_;
		_tmp6_ = prop;
		_tmp7_ = _tmp6_->value_type;
		_tmp8_ = g_type_is_a (_tmp7_, GXML_TYPE_GOM_PROPERTY);
		if (_tmp8_) {
			GParamSpec* _tmp9_ = NULL;
			const gchar* _tmp10_ = NULL;
			GXmlGomProperty* so = NULL;
			GValue _tmp11_ = {0};
			GObject* _tmp12_ = NULL;
			GXmlGomProperty* _tmp13_ = NULL;
			GXmlGomProperty* _tmp14_ = NULL;
			GXmlGomProperty* _tmp25_ = NULL;
			const gchar* _tmp26_ = NULL;
			_tmp9_ = prop;
			_tmp10_ = _tmp9_->name;
			g_object_get_property ((GObject*) self, _tmp10_, &v);
			_tmp11_ = v;
			_tmp12_ = g_value_get_object (&_tmp11_);
			_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_GOM_PROPERTY) ? ((GXmlGomProperty*) _tmp12_) : NULL);
			so = _tmp13_;
			_tmp14_ = so;
			if (_tmp14_ == NULL) {
				GObject* obj = NULL;
				GParamSpec* _tmp15_ = NULL;
				GType _tmp16_ = 0UL;
				GObject* _tmp17_ = NULL;
				GObject* _tmp18_ = NULL;
				GObject* _tmp19_ = NULL;
				GParamSpec* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				GValue _tmp22_ = {0};
				GObject* _tmp23_ = NULL;
				GXmlGomProperty* _tmp24_ = NULL;
				_tmp15_ = prop;
				_tmp16_ = _tmp15_->value_type;
				_tmp17_ = g_object_new (_tmp16_, NULL);
				_tmp18_ = G_IS_INITIALLY_UNOWNED (_tmp17_) ? g_object_ref_sink (_tmp17_) : _tmp17_;
				obj = _tmp18_;
				_tmp19_ = obj;
				g_value_set_object (&v, _tmp19_);
				_tmp20_ = prop;
				_tmp21_ = _tmp20_->name;
				_tmp22_ = v;
				g_object_set_property ((GObject*) self, _tmp21_, &_tmp22_);
				_tmp23_ = obj;
				_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_GOM_PROPERTY) ? ((GXmlGomProperty*) _tmp23_) : NULL);
				_g_object_unref0 (so);
				so = _tmp24_;
				_g_object_unref0 (obj);
			}
			_tmp25_ = so;
			_tmp26_ = val;
			gxml_gom_property_set_value (_tmp25_, _tmp26_);
			result = TRUE;
			_g_object_unref0 (so);
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			_g_param_spec_unref0 (prop);
			return result;
		}
		_tmp27_ = prop;
		_tmp28_ = _tmp27_->value_type;
		_tmp29_ = g_type_is_a (_tmp28_, G_TYPE_STRING);
		if (_tmp29_) {
			const gchar* _tmp30_ = NULL;
			GParamSpec* _tmp31_ = NULL;
			const gchar* _tmp32_ = NULL;
			GValue _tmp33_ = {0};
			_tmp30_ = val;
			g_value_set_string (&v, _tmp30_);
			_tmp31_ = prop;
			_tmp32_ = _tmp31_->name;
			_tmp33_ = v;
			g_object_set_property ((GObject*) self, _tmp32_, &_tmp33_);
			result = TRUE;
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			_g_param_spec_unref0 (prop);
			return result;
		}
		_tmp34_ = prop;
		_tmp35_ = _tmp34_->value_type;
		_tmp36_ = g_type_is_a (_tmp35_, G_TYPE_INT);
		if (_tmp36_) {
			gint iv = 0;
			const gchar* _tmp37_ = NULL;
			gdouble _tmp38_ = 0.0;
			gint _tmp39_ = 0;
			GParamSpec* _tmp40_ = NULL;
			const gchar* _tmp41_ = NULL;
			GValue _tmp42_ = {0};
			_tmp37_ = val;
			_tmp38_ = double_parse (_tmp37_);
			iv = (gint) _tmp38_;
			_tmp39_ = iv;
			g_value_set_int (&v, _tmp39_);
			_tmp40_ = prop;
			_tmp41_ = _tmp40_->name;
			_tmp42_ = v;
			g_object_set_property ((GObject*) self, _tmp41_, &_tmp42_);
			result = TRUE;
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			_g_param_spec_unref0 (prop);
			return result;
		}
		_tmp43_ = prop;
		_tmp44_ = _tmp43_->value_type;
		_tmp45_ = g_type_is_a (_tmp44_, G_TYPE_UINT);
		if (_tmp45_) {
			guint iv = 0U;
			const gchar* _tmp46_ = NULL;
			gdouble _tmp47_ = 0.0;
			guint _tmp48_ = 0U;
			GParamSpec* _tmp49_ = NULL;
			const gchar* _tmp50_ = NULL;
			GValue _tmp51_ = {0};
			_tmp46_ = val;
			_tmp47_ = double_parse (_tmp46_);
			iv = (guint) _tmp47_;
			_tmp48_ = iv;
			g_value_set_int (&v, (gint) _tmp48_);
			_tmp49_ = prop;
			_tmp50_ = _tmp49_->name;
			_tmp51_ = v;
			g_object_set_property ((GObject*) self, _tmp50_, &_tmp51_);
			result = TRUE;
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			_g_param_spec_unref0 (prop);
			return result;
		}
		_tmp52_ = prop;
		_tmp53_ = _tmp52_->value_type;
		_tmp54_ = g_type_is_a (_tmp53_, G_TYPE_DOUBLE);
		if (_tmp54_) {
			gdouble dv = 0.0;
			const gchar* _tmp55_ = NULL;
			gdouble _tmp56_ = 0.0;
			gdouble _tmp57_ = 0.0;
			GParamSpec* _tmp58_ = NULL;
			const gchar* _tmp59_ = NULL;
			GValue _tmp60_ = {0};
			_tmp55_ = val;
			_tmp56_ = double_parse (_tmp55_);
			dv = _tmp56_;
			_tmp57_ = dv;
			g_value_set_double (&v, _tmp57_);
			_tmp58_ = prop;
			_tmp59_ = _tmp58_->name;
			_tmp60_ = v;
			g_object_set_property ((GObject*) self, _tmp59_, &_tmp60_);
			result = TRUE;
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			_g_param_spec_unref0 (prop);
			return result;
		}
		_tmp61_ = prop;
		_tmp62_ = _tmp61_->value_type;
		_tmp63_ = g_type_is_a (_tmp62_, G_TYPE_BOOLEAN);
		if (_tmp63_) {
			gboolean bv = FALSE;
			const gchar* _tmp64_ = NULL;
			gboolean _tmp65_ = FALSE;
			gboolean _tmp66_ = FALSE;
			GParamSpec* _tmp67_ = NULL;
			const gchar* _tmp68_ = NULL;
			GValue _tmp69_ = {0};
			_tmp64_ = val;
			_tmp65_ = bool_parse (_tmp64_);
			bv = _tmp65_;
			_tmp66_ = bv;
			g_value_set_boolean (&v, _tmp66_);
			_tmp67_ = prop;
			_tmp68_ = _tmp67_->name;
			_tmp69_ = v;
			g_object_set_property ((GObject*) self, _tmp68_, &_tmp69_);
			result = TRUE;
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			_g_param_spec_unref0 (prop);
			return result;
		}
		_tmp70_ = prop;
		_tmp71_ = _tmp70_->value_type;
		_tmp72_ = g_type_is_a (_tmp71_, G_TYPE_ENUM);
		if (_tmp72_) {
			{
				GEnumValue* _tmp73_ = NULL;
				GParamSpec* _tmp74_ = NULL;
				GType _tmp75_ = 0UL;
				const gchar* _tmp76_ = NULL;
				GEnumValue* _tmp77_ = NULL;
				gint n = 0;
				GEnumValue* _tmp78_ = NULL;
				GEnumValue* _tmp79_ = NULL;
				gint _tmp80_ = 0;
				gint _tmp81_ = 0;
				gint _tmp82_ = 0;
				_tmp74_ = prop;
				_tmp75_ = _tmp74_->value_type;
				_tmp76_ = val;
				_tmp77_ = gxml_enumeration_parse (_tmp75_, _tmp76_, &_inner_error_);
				_tmp73_ = _tmp77_;
				if (G_UNLIKELY (_inner_error_ != NULL)) {
					goto __catch22_g_error;
				}
				_tmp78_ = _tmp73_;
				_tmp73_ = NULL;
				_tmp79_ = _tmp78_;
				_tmp80_ = (*_tmp79_).value;
				_tmp81_ = (gint) _tmp80_;
				_g_free0 (_tmp79_);
				n = _tmp81_;
				_tmp82_ = n;
				g_value_set_enum (&v, _tmp82_);
				_g_free0 (_tmp73_);
			}
			goto __finally22;
			__catch22_g_error:
			{
				const gchar* _tmp83_ = NULL;
				g_clear_error (&_inner_error_);
				_inner_error_ = NULL;
				_tmp83_ = _ ("Enumeration can't be parsed from string");
				g_warning ("GomObject.vala:265: %s", _tmp83_);
				result = FALSE;
				G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
				_g_param_spec_unref0 (prop);
				return result;
			}
			__finally22:
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				gboolean _tmp84_ = FALSE;
				G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
				_g_param_spec_unref0 (prop);
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
				g_clear_error (&_inner_error_);
				return _tmp84_;
			}
			result = TRUE;
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			_g_param_spec_unref0 (prop);
			return result;
		}
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
	}
	result = FALSE;
	_g_param_spec_unref0 (prop);
	return result;
}


gboolean gxml_gom_object_set_attribute (GXmlGomObject* self, const gchar* name, const gchar* val) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->set_attribute (self, name, val);
}


/**
   * Search a {@link GLib.Object} property with given name
   * and returns it, if it is a {@link DomElement}. If not found,
   * {@link DomElement.get_elements_by_tag_name} is called, returning
   * first node found. Tag name to use, is the given name parameter.
   *
   * @param name a name of this object's property of type {@link DomElement} or
   * first {@link DomNode} with that name in child nodes.
   *
   */
static GXmlDomElement* gxml_gom_object_real_get_child (GXmlGomObject* self, const gchar* name) {
	GXmlDomElement* result = NULL;
	GParamSpec* prop = NULL;
	GObjectClass* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GParamSpec* _tmp2_ = NULL;
	GParamSpec* _tmp3_ = NULL;
	GParamSpec* _tmp4_ = NULL;
	gboolean _tmp15_ = FALSE;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = G_OBJECT_GET_CLASS ((GObject*) self);
	_tmp1_ = name;
	_tmp2_ = g_object_class_find_property (_tmp0_, _tmp1_);
	_tmp3_ = _g_param_spec_ref0 (_tmp2_);
	prop = _tmp3_;
	_tmp4_ = prop;
	if (_tmp4_ != NULL) {
		GParamSpec* _tmp5_ = NULL;
		GType _tmp6_ = 0UL;
		gboolean _tmp7_ = FALSE;
		_tmp5_ = prop;
		_tmp6_ = _tmp5_->value_type;
		_tmp7_ = g_type_is_a (_tmp6_, GXML_TYPE_DOM_ELEMENT);
		if (_tmp7_) {
			GValue vo = {0};
			GParamSpec* _tmp8_ = NULL;
			GType _tmp9_ = 0UL;
			GValue _tmp10_ = {0};
			GParamSpec* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			GValue _tmp13_ = {0};
			GXmlDomElement* _tmp14_ = NULL;
			_tmp8_ = prop;
			_tmp9_ = _tmp8_->value_type;
			g_value_init (&_tmp10_, _tmp9_);
			vo = _tmp10_;
			_tmp11_ = prop;
			_tmp12_ = _tmp11_->name;
			g_object_get_property ((GObject*) self, _tmp12_, &vo);
			_tmp13_ = vo;
			_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (g_value_get_object (&_tmp13_), GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
			result = _tmp14_;
			G_IS_VALUE (&vo) ? (g_value_unset (&vo), NULL) : NULL;
			_g_param_spec_unref0 (prop);
			return result;
		}
	}
	_tmp15_ = gxml_dom_node_has_child_nodes (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) self) : NULL);
	if (_tmp15_) {
		GXmlDomHTMLCollection* els = NULL;
		const gchar* _tmp16_ = NULL;
		GXmlDomHTMLCollection* _tmp17_ = NULL;
		GXmlDomHTMLCollection* _tmp18_ = NULL;
		gint _tmp19_ = 0;
		gint _tmp20_ = 0;
		_tmp16_ = name;
		_tmp17_ = gxml_dom_element_get_elements_by_tag_name (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) self) : NULL, _tmp16_);
		els = _tmp17_;
		_tmp18_ = els;
		_tmp19_ = gee_collection_get_size ((GeeCollection*) _tmp18_);
		_tmp20_ = _tmp19_;
		if (_tmp20_ != 0) {
			GXmlDomHTMLCollection* _tmp21_ = NULL;
			GXmlDomElement* _tmp22_ = NULL;
			_tmp21_ = els;
			_tmp22_ = gxml_dom_html_collection_item (_tmp21_, 0);
			result = _tmp22_;
			_g_object_unref0 (els);
			_g_param_spec_unref0 (prop);
			return result;
		}
		_g_object_unref0 (els);
	}
	result = NULL;
	_g_param_spec_unref0 (prop);
	return result;
}


GXmlDomElement* gxml_gom_object_get_child (GXmlGomObject* self, const gchar* name) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->get_child (self, name);
}


/**
   * From a given property name of type {@link GomElement}, search all
   * child nodes with node's local name equal to property.
   */
static GXmlDomElementList* gxml_gom_object_real_find_elements (GXmlGomObject* self, const gchar* name) {
	GXmlDomElementList* result = NULL;
	GXmlDomElementList* l = NULL;
	GXmlDomElementList* _tmp0_ = NULL;
	GParamSpec* prop = NULL;
	GObjectClass* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GParamSpec* _tmp3_ = NULL;
	GParamSpec* _tmp4_ = NULL;
	GParamSpec* _tmp5_ = NULL;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = gxml_dom_element_list_new ();
	l = _tmp0_;
	_tmp1_ = G_OBJECT_GET_CLASS ((GObject*) self);
	_tmp2_ = name;
	_tmp3_ = g_object_class_find_property (_tmp1_, _tmp2_);
	_tmp4_ = _g_param_spec_ref0 (_tmp3_);
	prop = _tmp4_;
	_tmp5_ = prop;
	if (_tmp5_ != NULL) {
		GParamSpec* _tmp6_ = NULL;
		GType _tmp7_ = 0UL;
		gboolean _tmp8_ = FALSE;
		_tmp6_ = prop;
		_tmp7_ = _tmp6_->value_type;
		_tmp8_ = g_type_is_a (_tmp7_, GXML_TYPE_DOM_ELEMENT);
		if (_tmp8_) {
			GXmlDomElement* o = NULL;
			GParamSpec* _tmp9_ = NULL;
			GType _tmp10_ = 0UL;
			GObject* _tmp11_ = NULL;
			GObject* _tmp12_ = NULL;
			GXmlDomElement* _tmp13_ = NULL;
			_tmp9_ = prop;
			_tmp10_ = _tmp9_->value_type;
			_tmp11_ = g_object_new (_tmp10_, NULL);
			_tmp12_ = G_IS_INITIALLY_UNOWNED (_tmp11_) ? g_object_ref_sink (_tmp11_) : _tmp11_;
			_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp12_) : NULL;
			if (_tmp13_ == NULL) {
				_g_object_unref0 (_tmp12_);
			}
			o = _tmp13_;
			{
				GXmlDomNodeList* _n_list = NULL;
				GXmlDomNodeList* _tmp14_ = NULL;
				GXmlDomNodeList* _tmp15_ = NULL;
				gint _n_size = 0;
				GXmlDomNodeList* _tmp16_ = NULL;
				gint _tmp17_ = 0;
				gint _tmp18_ = 0;
				gint _n_index = 0;
				_tmp14_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
				_tmp15_ = _tmp14_;
				_n_list = _tmp15_;
				_tmp16_ = _n_list;
				_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
				_tmp18_ = _tmp17_;
				_n_size = _tmp18_;
				_n_index = -1;
				while (TRUE) {
					gint _tmp19_ = 0;
					gint _tmp20_ = 0;
					gint _tmp21_ = 0;
					GXmlDomNode* n = NULL;
					GXmlDomNodeList* _tmp22_ = NULL;
					gint _tmp23_ = 0;
					gpointer _tmp24_ = NULL;
					GXmlDomNode* _tmp25_ = NULL;
					GXmlDomNode* _tmp26_ = NULL;
					gchar* _tmp27_ = NULL;
					gchar* _tmp28_ = NULL;
					gchar* _tmp29_ = NULL;
					gchar* _tmp30_ = NULL;
					gchar* _tmp31_ = NULL;
					GXmlDomElement* _tmp32_ = NULL;
					gchar* _tmp33_ = NULL;
					gchar* _tmp34_ = NULL;
					gchar* _tmp35_ = NULL;
					gchar* _tmp36_ = NULL;
					gchar* _tmp37_ = NULL;
					gboolean _tmp38_ = FALSE;
					_tmp19_ = _n_index;
					_n_index = _tmp19_ + 1;
					_tmp20_ = _n_index;
					_tmp21_ = _n_size;
					if (!(_tmp20_ < _tmp21_)) {
						break;
					}
					_tmp22_ = _n_list;
					_tmp23_ = _n_index;
					_tmp24_ = gee_list_get ((GeeList*) _tmp22_, _tmp23_);
					n = (GXmlDomNode*) _tmp24_;
					_tmp25_ = n;
					if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, GXML_TYPE_DOM_ELEMENT)) {
						_g_object_unref0 (n);
						continue;
					}
					_tmp26_ = n;
					_tmp27_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp26_) : NULL);
					_tmp28_ = _tmp27_;
					_tmp29_ = _tmp28_;
					_tmp30_ = g_utf8_strdown (_tmp29_, (gssize) -1);
					_tmp31_ = _tmp30_;
					_tmp32_ = o;
					_tmp33_ = gxml_dom_element_get_local_name (_tmp32_);
					_tmp34_ = _tmp33_;
					_tmp35_ = _tmp34_;
					_tmp36_ = g_utf8_strdown (_tmp35_, (gssize) -1);
					_tmp37_ = _tmp36_;
					_tmp38_ = g_strcmp0 (_tmp31_, _tmp37_) == 0;
					_g_free0 (_tmp37_);
					_g_free0 (_tmp35_);
					_g_free0 (_tmp31_);
					_g_free0 (_tmp29_);
					if (_tmp38_) {
						GXmlDomElementList* _tmp39_ = NULL;
						GXmlDomNode* _tmp40_ = NULL;
						_tmp39_ = l;
						_tmp40_ = n;
						gee_abstract_collection_add ((GeeAbstractCollection*) _tmp39_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp40_) : NULL);
					}
					_g_object_unref0 (n);
				}
				_g_object_unref0 (_n_list);
			}
			_g_object_unref0 (o);
		}
	}
	result = l;
	_g_param_spec_unref0 (prop);
	return result;
}


GXmlDomElementList* gxml_gom_object_find_elements (GXmlGomObject* self, const gchar* name) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->find_elements (self, name);
}


/**
   * Search for a property and set it to null if possible returning true,
   * if value can't be removed or located, returns false without change.
   */
static gboolean gxml_gom_object_real_remove_attribute (GXmlGomObject* self, const gchar* name) {
	gboolean result = FALSE;
	GParamSpec* prop = NULL;
	GObjectClass* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GParamSpec* _tmp2_ = NULL;
	GParamSpec* _tmp3_ = NULL;
	GParamSpec* _tmp4_ = NULL;
	g_return_val_if_fail (name != NULL, FALSE);
	_tmp0_ = G_OBJECT_GET_CLASS ((GObject*) self);
	_tmp1_ = name;
	_tmp2_ = g_object_class_find_property (_tmp0_, _tmp1_);
	_tmp3_ = _g_param_spec_ref0 (_tmp2_);
	prop = _tmp3_;
	_tmp4_ = prop;
	if (_tmp4_ != NULL) {
		GValue v = {0};
		GValue _tmp5_ = {0};
		const gchar* _tmp6_ = NULL;
		GValue _tmp7_ = {0};
		g_value_init (&_tmp5_, G_TYPE_OBJECT);
		v = _tmp5_;
		_tmp6_ = name;
		_tmp7_ = v;
		g_object_set_property (G_TYPE_CHECK_INSTANCE_TYPE (self, G_TYPE_OBJECT) ? ((GObject*) self) : NULL, _tmp6_, &_tmp7_);
		result = TRUE;
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
		_g_param_spec_unref0 (prop);
		return result;
	}
	result = FALSE;
	_g_param_spec_unref0 (prop);
	return result;
}


gboolean gxml_gom_object_remove_attribute (GXmlGomObject* self, const gchar* name) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->remove_attribute (self, name);
}


/**
   * Convenient method to set an instance of given property's
   * name and initialize according to have same {@link DomNode.owner_document}
   * and set its {@link DomNode.parent_node} to this appending it as a child.
   * If property is a {@link GomCollection} it is initialize to use
   * this as its {@link GomCollection.element}.
   *
   * Instance is set ot object's property.
   *
   * Property should be a {@link GomElement} or {@link GomCollection}
   *
   * While an object could be created and set to a Object's property, it
   * is not correctly initialized by default. This method helps in the process.
   *
   * If Object's property has been set, this method overwrite it.
   *
   * {{{
   * class NodeA : GomObject {
   *   construct { try { initialize ("NodeA"); } catch { warning ("Can't initialize); }
   * }
   * class NodeB : GomObject {
   *   public NodeA node { get; set; }
   * }
   *
   * var nb = new NodeB ();
   * nb.create_instance_property ("node");
   * assert (nb.node != null);
   * }}}
   *
   * Returns: true if property has been set and initialized, false otherwise.
   */
static gboolean gxml_gom_object_real_set_instance_property (GXmlGomObject* self, const gchar* name) {
	gboolean result = FALSE;
	GParamSpec* prop = NULL;
	const gchar* _tmp0_ = NULL;
	GParamSpec* _tmp1_ = NULL;
	GParamSpec* _tmp2_ = NULL;
	GValue v = {0};
	GParamSpec* _tmp3_ = NULL;
	GType _tmp4_ = 0UL;
	GValue _tmp5_ = {0};
	GObject* obj = NULL;
	GParamSpec* _tmp6_ = NULL;
	GType _tmp7_ = 0UL;
	gboolean _tmp8_ = FALSE;
	GParamSpec* _tmp17_ = NULL;
	GType _tmp18_ = 0UL;
	gboolean _tmp19_ = FALSE;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (name != NULL, FALSE);
	_tmp0_ = name;
	_tmp1_ = gxml_gom_object_find_object_property_name (self, _tmp0_);
	prop = _tmp1_;
	_tmp2_ = prop;
	if (_tmp2_ == NULL) {
		result = FALSE;
		_g_param_spec_unref0 (prop);
		return result;
	}
	_tmp3_ = prop;
	_tmp4_ = _tmp3_->value_type;
	g_value_init (&_tmp5_, _tmp4_);
	v = _tmp5_;
	_tmp6_ = prop;
	_tmp7_ = _tmp6_->value_type;
	_tmp8_ = g_type_is_a (_tmp7_, GXML_TYPE_GOM_COLLECTION);
	if (_tmp8_) {
		GParamSpec* _tmp9_ = NULL;
		GType _tmp10_ = 0UL;
		GObject* _tmp11_ = NULL;
		GObject* _tmp12_ = NULL;
		GObject* _tmp13_ = NULL;
		GParamSpec* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		GValue _tmp16_ = {0};
		_tmp9_ = prop;
		_tmp10_ = _tmp9_->value_type;
		_tmp11_ = g_object_new (_tmp10_, "element", self, NULL);
		_tmp12_ = G_IS_INITIALLY_UNOWNED (_tmp11_) ? g_object_ref_sink (_tmp11_) : _tmp11_;
		_g_object_unref0 (obj);
		obj = _tmp12_;
		_tmp13_ = obj;
		g_value_set_object (&v, _tmp13_);
		_tmp14_ = prop;
		_tmp15_ = _tmp14_->name;
		_tmp16_ = v;
		g_object_set_property ((GObject*) self, _tmp15_, &_tmp16_);
		result = TRUE;
		_g_object_unref0 (obj);
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
		_g_param_spec_unref0 (prop);
		return result;
	}
	_tmp17_ = prop;
	_tmp18_ = _tmp17_->value_type;
	_tmp19_ = g_type_is_a (_tmp18_, GXML_TYPE_GOM_ELEMENT);
	if (_tmp19_) {
		GParamSpec* _tmp20_ = NULL;
		GType _tmp21_ = 0UL;
		GXmlDomDocument* _tmp22_ = NULL;
		GXmlDomDocument* _tmp23_ = NULL;
		GObject* _tmp24_ = NULL;
		GObject* _tmp25_ = NULL;
		GObject* _tmp35_ = NULL;
		GParamSpec* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		GValue _tmp38_ = {0};
		_tmp20_ = prop;
		_tmp21_ = _tmp20_->value_type;
		_tmp22_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) self);
		_tmp23_ = _tmp22_;
		_tmp24_ = g_object_new (_tmp21_, "owner-document", _tmp23_, NULL);
		_tmp25_ = G_IS_INITIALLY_UNOWNED (_tmp24_) ? g_object_ref_sink (_tmp24_) : _tmp24_;
		_g_object_unref0 (obj);
		obj = _tmp25_;
		{
			GObject* _tmp26_ = NULL;
			GXmlDomNode* _tmp27_ = NULL;
			GXmlDomNode* _tmp28_ = NULL;
			_tmp26_ = obj;
			_tmp27_ = gxml_dom_node_append_child ((GXmlDomNode*) self, (GXmlDomNode*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp26_) : NULL), &_inner_error_);
			_tmp28_ = _tmp27_;
			_g_object_unref0 (_tmp28_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				goto __catch23_g_error;
			}
		}
		goto __finally23;
		__catch23_g_error:
		{
			GError* e = NULL;
			const gchar* _tmp29_ = NULL;
			GError* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			gchar* _tmp32_ = NULL;
			gchar* _tmp33_ = NULL;
			e = _inner_error_;
			_inner_error_ = NULL;
			_tmp29_ = _ ("Error while attempting to instantiate property object: %s");
			_tmp30_ = e;
			_tmp31_ = _tmp30_->message;
			_tmp32_ = g_strdup_printf (_tmp29_, _tmp31_);
			_tmp33_ = _tmp32_;
			g_warning ("GomObject.vala:377: %s", _tmp33_);
			_g_free0 (_tmp33_);
			result = FALSE;
			_g_error_free0 (e);
			_g_object_unref0 (obj);
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			_g_param_spec_unref0 (prop);
			return result;
		}
		__finally23:
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			gboolean _tmp34_ = FALSE;
			_g_object_unref0 (obj);
			G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
			_g_param_spec_unref0 (prop);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return _tmp34_;
		}
		_tmp35_ = obj;
		g_value_set_object (&v, _tmp35_);
		_tmp36_ = prop;
		_tmp37_ = _tmp36_->name;
		_tmp38_ = v;
		g_object_set_property ((GObject*) self, _tmp37_, &_tmp38_);
		result = TRUE;
		_g_object_unref0 (obj);
		G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
		_g_param_spec_unref0 (prop);
		return result;
	}
	result = FALSE;
	_g_object_unref0 (obj);
	G_IS_VALUE (&v) ? (g_value_unset (&v), NULL) : NULL;
	_g_param_spec_unref0 (prop);
	return result;
}


gboolean gxml_gom_object_set_instance_property (GXmlGomObject* self, const gchar* name) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_GOM_OBJECT_GET_INTERFACE (self)->set_instance_property (self, name);
}


/**
   * Utility method to remove all instances of a property being child elements
   * of object. Is useful if you have a {@link GomElement} property, it should be
   * just one child of this type and you want to overwrite it.
   *
   * In this example you have defined an element MyClass to be child of
   * MyParentClass, but it should have just one element, once you set child_elements
   * it calls {@link clean_property_elements} using property's canonicals name.
   *
   * {{{
   *  public class MyClass : GomElement {
   *    public string name { get; set; }
   *  }
   *  public class MyParentClass : GomElement {
   *    private Myclass _child_elements = null;
   *    public MyClass child_elements {
   *      get { return _child_elements; }
   *      set {
   *        try {
   *          clean_property_elements ("child-elements");
   *          _child_elements = value;
   *          append_child (_child_elements);
   *        } catch (GLib.Error e) {
   *          warning (e.message);
   *        }
   *      }
   *    }
   *  }
   * }}}
   *
   * @param name property name to search value type, use canonical names.
   *
   * @throws DomError if property is not a {@link GomElement}.
   */
static void gxml_gom_object_real_clean_property_elements (GXmlGomObject* self, const gchar* name, GError** error) {
	GParamSpec* prop = NULL;
	GObjectClass* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GParamSpec* _tmp2_ = NULL;
	GParamSpec* _tmp3_ = NULL;
	GParamSpec* _tmp4_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (name != NULL);
	_tmp0_ = G_OBJECT_GET_CLASS ((GObject*) self);
	_tmp1_ = name;
	_tmp2_ = g_object_class_find_property (_tmp0_, _tmp1_);
	_tmp3_ = _g_param_spec_ref0 (_tmp2_);
	prop = _tmp3_;
	_tmp4_ = prop;
	if (_tmp4_ != NULL) {
		GParamSpec* _tmp5_ = NULL;
		GType _tmp6_ = 0UL;
		gboolean _tmp7_ = FALSE;
		GXmlDomElementList* l = NULL;
		const gchar* _tmp10_ = NULL;
		GXmlDomElementList* _tmp11_ = NULL;
		GXmlDomElementList* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		_tmp5_ = prop;
		_tmp6_ = _tmp5_->value_type;
		_tmp7_ = g_type_is_a (_tmp6_, GXML_TYPE_GOM_ELEMENT);
		if (!_tmp7_) {
			const gchar* _tmp8_ = NULL;
			GError* _tmp9_ = NULL;
			_tmp8_ = _ ("Can't set value. It is not a GXmlGomElement type");
			_tmp9_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_TYPE_MISMATCH_ERROR, _tmp8_);
			_inner_error_ = _tmp9_;
			g_propagate_error (error, _inner_error_);
			_g_param_spec_unref0 (prop);
			return;
		}
		_tmp10_ = name;
		_tmp11_ = gxml_gom_object_find_elements (self, _tmp10_);
		l = _tmp11_;
		_tmp12_ = l;
		_tmp13_ = gxml_dom_html_collection_get_length ((GXmlDomHTMLCollection*) _tmp12_);
		_tmp14_ = _tmp13_;
		if (_tmp14_ != 0) {
			{
				GXmlDomElementList* _e_list = NULL;
				GXmlDomElementList* _tmp15_ = NULL;
				GXmlDomElementList* _tmp16_ = NULL;
				gint _e_size = 0;
				GXmlDomElementList* _tmp17_ = NULL;
				gint _tmp18_ = 0;
				gint _tmp19_ = 0;
				gint _e_index = 0;
				_tmp15_ = l;
				_tmp16_ = _g_object_ref0 (_tmp15_);
				_e_list = _tmp16_;
				_tmp17_ = _e_list;
				_tmp18_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp17_);
				_tmp19_ = _tmp18_;
				_e_size = _tmp19_;
				_e_index = -1;
				while (TRUE) {
					gint _tmp20_ = 0;
					gint _tmp21_ = 0;
					gint _tmp22_ = 0;
					GXmlDomElement* e = NULL;
					GXmlDomElementList* _tmp23_ = NULL;
					gint _tmp24_ = 0;
					gpointer _tmp25_ = NULL;
					GXmlDomElement* _tmp26_ = NULL;
					_tmp20_ = _e_index;
					_e_index = _tmp20_ + 1;
					_tmp21_ = _e_index;
					_tmp22_ = _e_size;
					if (!(_tmp21_ < _tmp22_)) {
						break;
					}
					_tmp23_ = _e_list;
					_tmp24_ = _e_index;
					_tmp25_ = gee_abstract_list_get ((GeeAbstractList*) _tmp23_, _tmp24_);
					e = (GXmlDomElement*) _tmp25_;
					_tmp26_ = e;
					gxml_dom_child_node_remove ((GXmlDomChildNode*) _tmp26_);
					_g_object_unref0 (e);
				}
				_g_object_unref0 (_e_list);
			}
		}
		_g_object_unref0 (l);
	}
	_g_param_spec_unref0 (prop);
}


void gxml_gom_object_clean_property_elements (GXmlGomObject* self, const gchar* name, GError** error) {
	g_return_if_fail (self != NULL);
	GXML_GOM_OBJECT_GET_INTERFACE (self)->clean_property_elements (self, name, error);
}


static void gxml_gom_object_base_init (GXmlGomObjectIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		iface->get_properties_list = gxml_gom_object_real_get_properties_list;
		iface->find_property_name = gxml_gom_object_real_find_property_name;
		iface->find_object_property_name = gxml_gom_object_real_find_object_property_name;
		iface->get_property_element_list = gxml_gom_object_real_get_property_element_list;
		iface->get_property_string = gxml_gom_object_real_get_property_string;
		iface->get_attribute = gxml_gom_object_real_get_attribute;
		iface->set_attribute = gxml_gom_object_real_set_attribute;
		iface->get_child = gxml_gom_object_real_get_child;
		iface->find_elements = gxml_gom_object_real_find_elements;
		iface->remove_attribute = gxml_gom_object_real_remove_attribute;
		iface->set_instance_property = gxml_gom_object_real_set_instance_property;
		iface->clean_property_elements = gxml_gom_object_real_clean_property_elements;
	}
}


/**
 * A GXml Object Model (GOM) represents a {@link DomElement}. It has attributes
 * and children. All object's properties are handled as attributes if they are
 * basic types like integers, strings, enums and others; {@link SerializableProperty}
 * objects are handled as attributes too. If object's attribute is a {@link GLib.Object}
 * it is handled as node's child, but only if it is a {@link GomElement} object,
 * other wise it is ignored when this object is used as {@link DomNode} in XML
 * documents.
 */
GType gxml_gom_object_get_type (void) {
	static volatile gsize gxml_gom_object_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_object_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomObjectIface), (GBaseInitFunc) gxml_gom_object_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_gom_object_type_id;
		gxml_gom_object_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlGomObject", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_gom_object_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_gom_object_type_id, GXML_TYPE_DOM_NODE);
		g_type_interface_add_prerequisite (gxml_gom_object_type_id, GXML_TYPE_DOM_ELEMENT);
		g_once_init_leave (&gxml_gom_object_type_id__volatile, gxml_gom_object_type_id);
	}
	return gxml_gom_object_type_id__volatile;
}



